# Calcul de la perte de charge sur une grille de prise d'eau

## Grille conventionnelle

Plans de grille conventionnels&nbsp;: perpendiculaires à l'écoulement et peu inclinés par rapport à l'horizontale

### Formule

Utilisation de la formule F1 de Raynal et al. (2012) pour calculer les pertes de charge.

$$\xi = K_F * K_O * K_\beta = a * \left ( \frac{O}{1-O} \right )^{1.6} * \left ( 1 - \cos{\beta} \right )^{0.39}$$


## Grille orientée

Plans de grille orientés par rapport à l'écoulement et quasi-verticaux.

![Grille orientée](grille-orientee.jpg)

*Courret, D. et Larinier, M. Guide pour la conception de prise d’eau ichtyocompatibles pour les petites centrales hydroélectriques, 2008. https://doi.org/10.13140/RG.2.1.2359.1449.*

### Formule

Utilisation de la formule F2 de Raynal et al. (2012) pour calculer les pertes de charge.

$$\xi = K_F * K_O * K_\alpha = a * \left ( \frac{O}{1-O} \right )^{1.6} * \left ( 1 + c * \left ( \frac{90 - \alpha}{90} \right )^{2.35} * \left ( \frac{1 - O}{O} \right )^{3} \right )$$


## Grille inclinée

Plans de grille perpendiculaires à l'écoulement, et inclinés par rapport à l'horizontale

![Grille inclinée](grille-inclinee.jpg)

![Grille inclinée](grille-inclinee-b.jpg)

*Courret, D. et Larinier, M. Guide pour la conception de prise d’eau ichtyocompatibles pour les petites centrales hydroélectriques, 2008. https://doi.org/10.13140/RG.2.1.2359.1449.*

### Formule

Utilisation de la formule F3 de Raynal et al. (2012) pour calculer les pertes de charge.

$$\xi = K_{F, b} * K_b * K_\beta + K_{Fent} * K_{entH} = a * \left ( \frac{O_b}{1-O_b} \right )^{1.65} * \left ( \sin \beta \right )^{2} + c * \left ( \frac{O_{entH}}{1-O_{entH}} \right )^{0.77}$$



## Paramètres

### Cote du sommet immergé du plan de grille

Peut être différent du niveau d'eau si le sommet du plan de grille est noyé.

### Largeur de la section

#### grille conventionnelle ou inclinée

Doit également correspondre à la largeur du plan de grille.

### Vitesse d'approche moyenne pour le débit maximum turbiné, en soustrayant la partie supérieure éventuellement obturée

Valeur "maximalisée" de la vitesse d'approche prise en compte dans le calcul du perte de charge, dans une approche sécuritaire.

### Inclinaison par rapport à l'horizontale

#### grille conventionnelle

Domaine de validité de la formule&nbsp;: 45 ≤ β ≤ 90°

#### grille orientée

Plans de grille verticaux (β = 90°).

La légère inclinaison des plans de grille (β≈ 75/80°), souvent mise en place pour des questions de dégrillage, peut être négligée.

#### grille inclinée

Domaine de validité de la formule&nbsp;: 15° ≤ β ≤ 90°
Préconisation pour le guidage des poissons&nbsp;: β ≤ 26°

### Orientation par rapport à la direction de l'écoulement

#### grille conventionnelle

Plans de grille perpendiculaires à l'écoulement (α = 90°)

#### grille orientée

Domaine de validité de la formule&nbsp;: 30° ≤ α ≤ 90°

Préconisation pour le guidage des poissons&nbsp;: α ≤ 45°

#### grille inclinée

Plans de grille perpendiculaires à l'écoulement (α = 90°)

### Vitesse normale moyenne pour le débit maximum turbiné

#### grille conventionnelle

Préconisation pour éviter le placage des poissons sur le plan de grille (barrière physique) ou leur passage prématuré au travers (barrière comportementale)&nbsp;: VN ≤ 0.5 m/s.

#### grille orientée ou inclinée

Préconisation pour éviter le placage des poissons sur le plan de grille (barrière physique) ou leur passage prématuré au travers (barrière comportementale)&nbsp;: VN ≤ 0.5 m/s.

Au-delà de la valeur moyenne calculée ici, se reporter impérativement aux préconisations tirées de la caractérisation expérimentale des valeurs effectives de vitesses.

### Rapport de forme des barreaux

#### grille orientée

Domaine de validité de la formule&nbsp;: rapport b / p voisin de 0.125

### Rapport espacement/épaisseur des barreaux

#### grille orientée

Domaine de validité de la formule&nbsp;: 1 ≤ e / b ≤ 3

### Obstruction globale du plan de grille (barreaux + entretoises + éléments de supports longitudinaux et transversaux) retenue

A déterminer à partir des plans de la grille.

#### grille conventionnelle

Domaine de validité de la formule&nbsp;: 0.2 ≤ O ≤ 0.60

#### grille orientée

Domaine de validité de la formule&nbsp;: 0.35 ≤ O ≤ 0.60

#### grille inclinée

Obstruction due aux barreaux et éléments de supports longitudinaux retenue \(O_b\). A déterminer à partir des plans de la grille.

Domaine de validité de la formule&nbsp;: 0.28 ≤ Ob ≤ 0.53

### Profil des barreaux

![Profil des barreaux](profil-barreaux.png)

*Raynal, Sylvain. « Étude expérimentale et numérique des grilles ichtyocompatibles ». Sciences et ingénierie en matériaux, mécanique, énergétique et aéronautique - SIMMEA, 2013.*

#### grille conventionnelle

Le coefficient de forme des barreaux \(a\) vaut 2.89 pour le profil rectangulaire (PR) et 1.70 pour le profil hydrodynamique (PH).

#### grille orientée

Le coefficient de forme des barreaux \(a\) vaut 2.89 pour le profil rectangulaire (PR) et 1.70 pour le profil hydrodynamique (PH).

Le coefficient de forme des barreaux \(c\) vaut 1.69 pour le profil rectangulaire (PR) et 2.78 pour le profil hydrodynamique (PH).

#### grille inclinée

Le coefficient de forme des barreaux \(a\) vaut 3.85 pour le profil rectangulaire (PR) et 2.10 pour le profil hydrodynamique (PH).

### Obstruction effective due aux entretoises et éléments de support transversaux rapportée à la section d'écoulement

#### grille inclinée

A déterminer à partir des plans de la grille.
Domaine de validité de la formule&nbsp;: OentH ≤ 0.28

### Coefficient de forme moyen des entretoises et éléments transversaux, pondérés selon leurs parts respectives

#### grille inclinée

A déterminer à partir des plans de la grille.

Vaut par exemple 1.79 pour les entretoises cylindriques, 2.42 pour les entretoises rectangulaires, et de l'ordre de 4 pour les poutres carrées et IPN.
