import { AppPage } from "./app.po";
import { Navbar } from "./navbar.po";
import { SideNav } from "./sidenav.po";
import { browser, element, by } from "protractor";

/**
 * Load 4 malformed session files :
 *  - one having an format version too old
 *  - one having an empty list of modules
 *  - one having missing mandatory data (ex: parameter symbol)
 *  - one having malformed JSON syntax
 * @WARNING error messages are tested in french
 */
describe("ngHyd − load malformed session files − ", () => {
  let startPage: AppPage;
  let navbar: Navbar;
  let sidenav: SideNav;

  function init() {
      startPage = new AppPage();
      navbar = new Navbar();
      sidenav = new SideNav();
  }
  beforeEach(init);

   it("when loading session-bad-syntax.json, displayed error should be relevant", async () => {
    await startPage.navigateTo();

    await navbar.clickMenuButton();
    await browser.sleep(200);

    await sidenav.clickLoadSessionButton();
    await browser.sleep(200);

    await sidenav.loadSessionFile("./session/session-bad-syntax.json");
    const err = element(by.css(".file-problem .mat-list-item-content"));
    expect(await err.getText()).toContain("La syntaxe du fichier semble incorrecte");
  });

  it("when loading session-missing-info.json, displayed error should be relevant", async () => {
   await startPage.navigateTo();

   await navbar.clickMenuButton();
   await browser.sleep(200);

   await sidenav.clickLoadSessionButton();
   await browser.sleep(200);

   await sidenav.loadSessionFile("./session/session-missing-info.json");
   const err = element(by.css(".file-problem .mat-list-item-content"));
   expect(await err.getText()).toContain("La syntaxe du fichier semble incorrecte");
 });

 it("when loading session-empty-modules-list.json, displayed error should be relevant", async () => {
  await startPage.navigateTo();

  await navbar.clickMenuButton();
  await browser.sleep(200);

  await sidenav.clickLoadSessionButton();
  await browser.sleep(200);

  await sidenav.loadSessionFile("./session/session-empty-modules-list.json");
  const err = element(by.css(".file-problem .mat-list-item-content"));
  expect(await err.getText()).toContain("Le fichier ne contient aucun module");
});

it("when loading session-format-too-old.json, displayed error should be relevant", async () => {
 await startPage.navigateTo();

 await navbar.clickMenuButton();
 await browser.sleep(200);

 await sidenav.clickLoadSessionButton();
 await browser.sleep(200);

 await sidenav.loadSessionFile("./session/session-format-too-old.json", false);
 const err = element(by.css(".file-problem .mat-list-item-content"));
 expect(await err.getText()).toContain("Mauvaise version du format de fichier");
});

});
